@@ -1,7 +1,7 @@
 package Acme::CPANModules::PortedFrom::Java;
 
-our $DATE = '2020-02-07'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2021-03-15'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 our $LIST = {
     summary => "Modules/applications that are ported from (or inspired by) ".
@@ -42,15 +42,13 @@ Acme::CPANModules::PortedFrom::Java - Modules/applications that are ported from
 
 =head1 VERSION
 
-This document describes version 0.002 of Acme::CPANModules::PortedFrom::Java (from Perl distribution Acme-CPANModules-PortedFrom-Java), released on 2020-02-07.
+This document describes version 0.003 of Acme::CPANModules::PortedFrom::Java (from Perl distribution Acme-CPANModules-PortedFrom-Java), released on 2021-03-15.
 
 =head1 DESCRIPTION
 
-Modules/applications that are ported from (or inspired by) Java.
-
 If you know of others, please drop me a message.
 
-=head1 INCLUDED MODULES
+=head1 ACME::MODULES ENTRIES
 
 =over
 
@@ -64,10 +62,17 @@ If you know of others, please drop me a message.
 
 =head1 FAQ
 
-=head2 What are ways to use this module?
+=head2 What is an Acme::CPANModules::* module?
 
-Aside from reading it, you can install all the listed modules using
-L<cpanmodules>:
+An Acme::CPANModules::* module, like this module, contains just a list of module
+names that share a common characteristics. It is a way to categorize modules and
+document CPAN. See L<Acme::CPANModules> for more details.
+
+=head2 What are ways to use this Acme::CPANModules module?
+
+Aside from reading this Acme::CPANModules module's POD documentation, you can
+install all the listed modules (entries) using L<cpanmodules> CLI (from
+L<App::cpanmodules> distribution):
 
     % cpanmodules ls-entries PortedFrom::Java | cpanm -n
 
@@ -75,9 +80,13 @@ or L<Acme::CM::Get>:
 
     % perl -MAcme::CM::Get=PortedFrom::Java -E'say $_->{module} for @{ $LIST->{entries} }' | cpanm -n
 
-This module also helps L<lcpan> produce a more meaningful result for C<lcpan
-related-mods> when it comes to finding related modules for the modules listed
-in this Acme::CPANModules module.
+or directly:
+
+    % perl -MAcme::CPANModules::PortedFrom::Java -E'say $_->{module} for @{ $Acme::CPANModules::PortedFrom::Java::LIST->{entries} }' | cpanm -n
+
+This Acme::CPANModules module also helps L<lcpan> produce a more meaningful
+result for C<lcpan related-mods> command when it comes to finding related
+modules for the modules listed in this Acme::CPANModules module.
 
 =head1 HOMEPAGE
 
@@ -89,7 +98,7 @@ Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModules-Por
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModules-PortedFrom-Java>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Acme-CPANModules-PortedFrom-Java/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -97,6 +106,14 @@ feature.
 
 =head1 SEE ALSO
 
+More on the same theme of modules ported from other languages:
+L<Acme::CPANModules::PortedFrom::Clojure>,
+L<Acme::CPANModules::PortedFrom::Go>,
+L<Acme::CPANModules::PortedFrom::NPM>,
+L<Acme::CPANModules::PortedFrom::PHP>,
+L<Acme::CPANModules::PortedFrom::Python>,
+L<Acme::CPANModules::PortedFrom::Ruby>.
+
 L<Acme::CPANModules> - about the Acme::CPANModules namespace
 
 L<cpanmodules> - CLI tool to let you browse/view the lists
@@ -107,7 +124,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
